var searchData=
[
  ['sacrificeattack',['SacrificeAttack',['../classosl_1_1move__probability_1_1SacrificeAttack.html',1,'osl::move_probability']]],
  ['sacrificecheck',['SacrificeCheck',['../structosl_1_1search_1_1SacrificeCheck.html',1,'osl::search']]],
  ['safecapture',['SafeCapture',['../structosl_1_1effect__util_1_1EffectUtil_1_1SafeCapture.html',1,'osl::effect_util::EffectUtil']]],
  ['safedropmajorpiece',['SafeDropMajorPiece',['../structosl_1_1move__generator_1_1SafeDropMajorPiece.html',1,'osl::move_generator']]],
  ['safemove',['SafeMove',['../structosl_1_1move__classifier_1_1SafeMove.html',1,'osl::move_classifier']]],
  ['searchallmoves',['SearchAllMoves',['../classosl_1_1game__playing_1_1SpeculativeAllMoves_1_1SearchAllMoves.html',1,'osl::game_playing::SpeculativeAllMoves']]],
  ['searchbase',['SearchBase',['../structosl_1_1search_1_1SearchBase.html',1,'osl::search']]],
  ['searchbase_3c_20evalt_2c_20simplehashtable_2c_20countrecorder_2c_20realizationprobability_20_3e',['SearchBase&lt; EvalT, SimpleHashTable, CountRecorder, RealizationProbability &gt;',['../structosl_1_1search_1_1SearchBase.html',1,'osl::search']]],
  ['searcher',['Searcher',['../classSearcher.html',1,'']]],
  ['searchinfo',['SearchInfo',['../structosl_1_1search_1_1AlphaBeta3_1_1SearchInfo.html',1,'osl::search::AlphaBeta3']]],
  ['searchinfo',['SearchInfo',['../structosl_1_1record_1_1SearchInfo.html',1,'osl::record']]],
  ['searchmonitor',['SearchMonitor',['../classosl_1_1search_1_1SearchMonitor.html',1,'osl::search']]],
  ['searchplayer',['SearchPlayer',['../classosl_1_1game__playing_1_1SearchPlayer.html',1,'osl::game_playing']]],
  ['searchrecorder',['SearchRecorder',['../classosl_1_1search_1_1SearchRecorder.html',1,'osl::search']]],
  ['searchstate2',['SearchState2',['../classosl_1_1search_1_1SearchState2.html',1,'osl::search']]],
  ['searchstate2core',['SearchState2Core',['../classosl_1_1search_1_1SearchState2Core.html',1,'osl::search']]],
  ['searchstate2shared',['SearchState2Shared',['../structosl_1_1search_1_1SearchState2Shared.html',1,'osl::search']]],
  ['searchtable',['SearchTable',['../structosl_1_1search_1_1SearchTable.html',1,'osl::search']]],
  ['searchtimer',['SearchTimer',['../classosl_1_1search_1_1SearchTimer.html',1,'osl::search']]],
  ['searchtimercommon',['SearchTimerCommon',['../structosl_1_1search_1_1SearchTimerCommon.html',1,'osl::search']]],
  ['see',['See',['../structosl_1_1eval_1_1See.html',1,'osl::eval']]],
  ['seefeature',['SeeFeature',['../classosl_1_1move__probability_1_1SeeFeature.html',1,'osl::move_probability']]],
  ['selectsafepieces',['SelectSafePieces',['../structosl_1_1eval_1_1SelectSafePieces.html',1,'osl::eval']]],
  ['sendoff',['SendOff',['../classosl_1_1move__probability_1_1SendOff.html',1,'osl::move_probability']]],
  ['sendoff',['SendOff',['../classosl_1_1rating_1_1SendOff.html',1,'osl::rating']]],
  ['sendoffgroup',['SendOffGroup',['../classosl_1_1rating_1_1SendOffGroup.html',1,'osl::rating']]],
  ['sendoffsquare',['SendOffSquare',['../structosl_1_1effect__util_1_1SendOffSquare.html',1,'osl::effect_util']]],
  ['sennichite',['Sennichite',['../classosl_1_1Sennichite.html',1,'osl']]],
  ['shadoweffect',['ShadowEffect',['../structosl_1_1effect__util_1_1ShadowEffect.html',1,'osl::effect_util']]],
  ['shadoweffect1',['ShadowEffect1',['../classosl_1_1rating_1_1ShadowEffect1.html',1,'osl::rating']]],
  ['shadoweffect2',['ShadowEffect2',['../classosl_1_1rating_1_1ShadowEffect2.html',1,'osl::rating']]],
  ['shadoweffectgroup',['ShadowEffectGroup',['../structosl_1_1rating_1_1ShadowEffectGroup.html',1,'osl::rating']]],
  ['shared',['Shared',['../structosl_1_1checkmate_1_1DualDfpn_1_1Shared.html',1,'osl::checkmate::DualDfpn']]],
  ['shortpieceaction',['ShortPieceAction',['../classosl_1_1move__generator_1_1without__effect_1_1ShortPieceAction.html',1,'osl::move_generator::without_effect']]],
  ['shortpieceaction',['ShortPieceAction',['../classosl_1_1move__generator_1_1addeffect8_1_1ShortPieceAction.html',1,'osl::move_generator::addeffect8']]],
  ['shouldpromotecut',['ShouldPromoteCut',['../structosl_1_1search_1_1ShouldPromoteCut.html',1,'osl::search']]],
  ['signatureeffect',['SignatureEffect',['../classosl_1_1effect_1_1SignatureEffect.html',1,'osl::effect']]],
  ['signaturetable',['SignatureTable',['../classosl_1_1effect_1_1SignatureTable.html',1,'osl::effect']]],
  ['signaturetraits',['SignatureTraits',['../structosl_1_1effect_1_1SignatureTraits.html',1,'osl::effect']]],
  ['silveradvance26',['SilverAdvance26',['../classosl_1_1eval_1_1ml_1_1SilverAdvance26.html',1,'osl::eval::ml']]],
  ['silverfeatures',['SilverFeatures',['../classosl_1_1eval_1_1ml_1_1SilverFeatures.html',1,'osl::eval::ml']]],
  ['silverfork',['SilverFork',['../classosl_1_1eval_1_1ml_1_1SilverFork.html',1,'osl::eval::ml']]],
  ['silverheadpawnkingrelative',['SilverHeadPawnKingRelative',['../classosl_1_1eval_1_1ml_1_1SilverHeadPawnKingRelative.html',1,'osl::eval::ml']]],
  ['silverretreat',['SilverRetreat',['../classosl_1_1eval_1_1ml_1_1SilverRetreat.html',1,'osl::eval::ml']]],
  ['simplebettertopromote',['SimpleBetterToPromote',['../classosl_1_1effect__action_1_1SimpleBetterToPromote.html',1,'osl::effect_action']]],
  ['simplehashrecord',['SimpleHashRecord',['../classosl_1_1search_1_1SimpleHashRecord.html',1,'osl::search']]],
  ['simplehashtable',['SimpleHashTable',['../classosl_1_1search_1_1SimpleHashTable.html',1,'osl::search']]],
  ['simplemove',['SimpleMove',['../classosl_1_1effect__action_1_1SimpleMove.html',1,'osl::effect_action']]],
  ['simplepin',['SimplePin',['../classosl_1_1eval_1_1ml_1_1SimplePin.html',1,'osl::eval::ml']]],
  ['simplepredictor',['SimplePredictor',['../classosl_1_1enter__king_1_1SimplePredictor.html',1,'osl::enter_king']]],
  ['simplestate',['SimpleState',['../classosl_1_1state_1_1SimpleState.html',1,'osl::state']]],
  ['simpletwinlist',['SimpleTwinList',['../structosl_1_1checkmate_1_1SimpleTwinList.html',1,'osl::checkmate']]],
  ['slist',['slist',['../structosl_1_1stl_1_1slist.html',1,'osl::stl']]],
  ['sortcapturemoves',['SortCaptureMoves',['../structosl_1_1search_1_1SortCaptureMoves.html',1,'osl::search']]],
  ['speculativeallmoves',['SpeculativeAllMoves',['../classosl_1_1game__playing_1_1SpeculativeAllMoves.html',1,'osl::game_playing']]],
  ['speculativemodel',['SpeculativeModel',['../classosl_1_1game__playing_1_1SpeculativeModel.html',1,'osl::game_playing']]],
  ['speculativesearchplayer',['SpeculativeSearchPlayer',['../classosl_1_1game__playing_1_1SpeculativeSearchPlayer.html',1,'osl::game_playing']]],
  ['square',['Square',['../classosl_1_1Square.html',1,'osl']]],
  ['square8',['Square8',['../structosl_1_1container_1_1Square8.html',1,'osl::container']]],
  ['squarecompressor',['SquareCompressor',['../structosl_1_1SquareCompressor.html',1,'osl']]],
  ['squarex',['SquareX',['../classosl_1_1rating_1_1SquareX.html',1,'osl::rating']]],
  ['squarex',['SquareX',['../classosl_1_1move__probability_1_1SquareX.html',1,'osl::move_probability']]],
  ['squarexgroup',['SquareXGroup',['../structosl_1_1rating_1_1SquareXGroup.html',1,'osl::rating']]],
  ['squarey',['SquareY',['../classosl_1_1rating_1_1SquareY.html',1,'osl::rating']]],
  ['squarey',['SquareY',['../classosl_1_1move__probability_1_1SquareY.html',1,'osl::move_probability']]],
  ['squareygroup',['SquareYGroup',['../structosl_1_1rating_1_1SquareYGroup.html',1,'osl::rating']]],
  ['stack',['stack',['../structosl_1_1stl_1_1stack.html',1,'osl::stl']]],
  ['stack',['Stack',['../structosl_1_1game__playing_1_1TimeKeeper_1_1Stack.html',1,'osl::game_playing::TimeKeeper']]],
  ['standardcharacters',['StandardCharacters',['../structosl_1_1record_1_1StandardCharacters.html',1,'osl::record']]],
  ['standardfeatureset',['StandardFeatureSet',['../classosl_1_1move__probability_1_1StandardFeatureSet.html',1,'osl::move_probability']]],
  ['standardfeatureset',['StandardFeatureSet',['../classosl_1_1rating_1_1StandardFeatureSet.html',1,'osl::rating']]],
  ['standelements',['StandElements',['../structosl_1_1search_1_1StandElements.html',1,'osl::search']]],
  ['standhash',['StandHash',['../structosl_1_1hash_1_1HashKey128_1_1StandHash.html',1,'osl::hash::HashKey128']]],
  ['state',['State',['../structosl_1_1game__playing_1_1GameState_1_1State.html',1,'osl::game_playing::GameState']]],
  ['state',['State',['../structosl_1_1misc_1_1BinaryReader_1_1State.html',1,'osl::misc::BinaryReader']]],
  ['state',['State',['../structState.html',1,'']]],
  ['state',['State',['../structosl_1_1misc_1_1BinaryElementReader_1_1State.html',1,'osl::misc::BinaryElementReader']]],
  ['stateelements',['StateElements',['../structosl_1_1search_1_1StateElements.html',1,'osl::search']]],
  ['stateinfo',['StateInfo',['../structosl_1_1move__probability_1_1StateInfo.html',1,'osl::move_probability']]],
  ['statepredicate',['StatePredicate',['../classStatePredicate.html',1,'']]],
  ['staticinitializetracer',['StaticInitializeTracer',['../structosl_1_1misc_1_1StaticInitializeTracer.html',1,'osl::misc']]],
  ['statistics',['Statistics',['../structosl_1_1rating_1_1FeatureSet_1_1Statistics.html',1,'osl::rating::FeatureSet']]],
  ['statuslock',['StatusLock',['../structosl_1_1game__playing_1_1SpeculativeAllMoves_1_1SearchAllMoves_1_1StatusLock.html',1,'osl::game_playing::SpeculativeAllMoves::SearchAllMoves']]],
  ['store',['Store',['../structosl_1_1search_1_1Store.html',1,'osl::search']]],
  ['store',['Store',['../structosl_1_1move__action_1_1Store.html',1,'osl::move_action']]],
  ['storepiece',['StorePiece',['../structosl_1_1effect__action_1_1StorePiece.html',1,'osl::effect_action']]],
  ['storeptypeosquare',['StorePtypeOSquare',['../structosl_1_1effect__action_1_1StorePtypeOSquare.html',1,'osl::effect_action']]],
  ['sumdiffnthpower',['SumDiffNthPower',['../structosl_1_1misc_1_1SumDiffNthPower.html',1,'osl::misc']]]
];
